@@ -9,6 +9,7 @@
 #'
 #' @examples
 #'
+#' suppressPackageStartupMessages(library("dplyr"))
 #'
 #' datasets::mtcars %>%
 #'   # tibble::rownames_to_column() not currently re-exported by dplyr
@@ -33,11 +34,15 @@ add_rank_indices <- function(.data,
     arrangeTerms <- colnames(.data)
   }
   # from: https://github.com/tidyverse/rlang/issues/116
-  arrangeTerms <- lapply(arrangeTerms,
-                         function(si) { rlang::parse_expr(si) })
-  .data <- arrange(.data, !!!arrangeTerms)
+  env <- parent.frame()
+  arrangeQ <- lapply(arrangeTerms,
+                    function(si) {
+                      rlang::parse_quosure(si,
+                                           env = env)
+                    })
+  .data <- dplyr::arrange(.data, !!!arrangeQ)
   # add ordered row-ids globally
-  d <- mutate(.data, !!orderColumn := 1 )
-  d <- mutate(d, !!orderColumn := cumsum(!!rlang::sym(orderColumn)) )
+  d <- dplyr::mutate(.data, !!orderColumn := 1 )
+  d <- dplyr::mutate(d, !!orderColumn := cumsum(!!rlang::sym(orderColumn)) )
   d
 }
