@@ -25,8 +25,18 @@ select_se <- function(.data, colNames) {
   # select(.data, one_of(colNames))
   # convert char vector into spliceable vector
   # use full parse instead of sym() to allow -var forms
+  # colSyms <- lapply(colNames,
+  #                   function(si) { rlang::parse_expr(si) })
+  # parse_expr sees into global environment
+  #  https://github.com/tidyverse/dplyr/issues/3006
+  env <- new.env(parent = emptyenv())
+  assign('-', `-`, envir = env)
+  assign('(', `(`, envir = env)
   colSyms <- lapply(colNames,
-                    function(si) { rlang::parse_expr(si) })
+                    function(si) {
+                      rlang::parse_quosure(si,
+                                           env = env)
+                    })
   dplyr::select(.data, !!!colSyms)
 }
 
