@@ -7,6 +7,10 @@ c('a' := 5, 'b' := 6)
 
 c('a', 'b') := c(5, 6)
 
+## ----key1----------------------------------------------------------------
+key = 'keycode'
+key := 'value'
+
 ## ----ex2-----------------------------------------------------------------
 suppressPackageStartupMessages(library("dplyr"))
 
@@ -27,5 +31,4 @@ datasets::iris %>%
 
 ## ----print, eval=FALSE---------------------------------------------------
 #  help(`:=`, package = 'seplyr')
-#  print(`:=`)
 
